<?php
include_once( ABSPATH . 'wp-admin/includes/image.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// テーマ用変数

if ( ! isset( $brightness_threshold ) )
	$brightness_threshold = 178.5;


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// テーマ用関数

require_once( get_template_directory() . '/inc/functions/theme-functions.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// $content_width

if ( ! isset( $content_width ) ) {
	$content_width = 570;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// 自動更新ライセンス

require_once( get_template_directory() . '/inc/license/class-ns-license-manager-client.php' );

if ( is_admin() ) {
	$ns_theme_license = new NS_License_Manager_Client(
		'new-standard-2',
		'New Standard バージョン2'
	);
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// テーマのセットアップ

add_action( 'after_setup_theme', 'nsd_setup_theme' );
if ( ! function_exists( 'nsd_setup_theme' ) ) {
	function nsd_setup_theme() {
		// 投稿アイキャッチ対応
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 360, 240, true );
		
		// 画像サイズ
		add_image_size( 'page-eyecatch', 1200, 800 );
		add_image_size( 'post-single-eyecatch', 700, 525 );
		add_image_size( 'thumbnail-small', 100, 100, true );
		
		// HTML5対応
		add_theme_support( 'html5', array(
			'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
		) );
		
		// エディタのCSS
		add_editor_style( get_template_directory_uri() . '/css/editor-style.css?ver=' . wp_theme_version() );
		
		// カスタムメニュー
		register_nav_menu( 'mainmenu', 'メインメニュー' );
	}
}

add_action( 'init', 'nsd_init_theme' );
function nsd_init_theme() {
	// 投稿ページの抜粋対応解除
	remove_post_type_support( 'post', 'excerpt' );
	
	// 固定ページの抜粋対応
	add_post_type_support( 'page', 'excerpt' );
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// テーマのアクティベイト時処理（必須）
// テーマのアクティベイト時処理（アクティベート時に1度しか行わない処理）
// MW WP Form のセットアップ

require_once( get_template_directory() . '/inc/functions/theme-setup.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// CSS, Javascript
// カスタマイズCSS
// ビジュアルエディタのカスタマイズCSS
// スマートフォン表示では管理バーを非表示
// カスタマイザー対応CSS

require_once( get_template_directory() . '/inc/functions/scripts-and-styles.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー カスタム投稿タイプ設定
// FAQカテゴリー 作成ページ
// FAQカテゴリー 編集ページ
// FAQカテゴリー CSS
// FAQカテゴリー Javascript
// FAQカテゴリー 並べ替え
// FAQカテゴリー 関数
// FAQカテゴリー 更新メッセージ

require_once( get_template_directory() . '/inc/functions/post-type-faq.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Advanced Custom Fields 設定
// Advanced Custom Fields のoptionフィールド バージョン互換
// Advanced Custom Fields のoptionフィールド 未設定時にデフォルト値を取得
// Advanced Custom Fields のCSS調整
// input type="number" のスクロールホイールをキャンセル (Advanced Custom Fields)
// テーマ設定ページ (Advanced Custom Fields)

require_once( get_template_directory() . '/inc/functions/acf-setup.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// ウィジェット追加

require_once( get_template_directory() . '/inc/functions/widget-setup.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// サイドバー設定

require_once( get_template_directory() . '/inc/functions/sidebar-setup.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// NS Shortcode

require_once( get_template_directory() . '/inc/functions/shortcode-functions.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// TinyMCE

require_once( get_template_directory() . '/inc/tinymce/tinymce.php' );


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// SEO

add_action( 'wp_head', 'nsd_add_seo_scripts' );
function nsd_add_seo_scripts() {
	if ( function_exists( 'get_field' ) ) {
		// description
		$description = get_field( 'nsd_seo_description', 'option' );
		if ( is_string( $description ) && '' !== $description ) {
			echo '<meta name="description" content="' . esc_attr( $description ) . '">' . "\n";
		}
		
		// keywords
		$keywords = get_field( 'nsd_seo_keywords', 'option' );
		if ( is_string( $keywords ) && '' !== $keywords ) {
			echo '<meta name="keywords" content="' . esc_attr( $keywords ) . '">' . "\n";
		}
		
		// Google アナリティクス
		$analytics_id = get_field( 'nsd_seo_analytics', 'option' );
		if ( preg_match( '/^UA\-\d+\-\d+$/i', $analytics_id) ) {
?>
<script>
	(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
	(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
	m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
	})(window,document,'script','https://www.google-analytics.com/analytics.js','ga');
	
	ga('create', '<?php echo esc_attr( $analytics_id ); ?>', 'auto');
	ga('send', 'pageview');
</script>
<?php
		}
		
		// Google サーチコンソール
		$search_console = get_field( 'nsd_seo_search_console', 'option' );
		if ( preg_match( '/^<meta [^>]*name="google-site-verification"[^>]*content="[^">]*"[^>]*>$/i', $search_console ) ) {
			echo $search_console . "\n";
		} elseif( preg_match( '/^[^<>"]+$/', $search_console ) ) {
			echo '<meta name="google-site-verification" content="' . esc_attr( $search_console ) . '">' . "\n";
		}
	}
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// メインメニューの項目数を5件に制限・クラスを追加

add_filter( 'wp_nav_menu_objects', 'nsd_mainmenu_limit', 10, 2 );
function nsd_mainmenu_limit( $sorted_menu_items, $args ) {
	$parent_item_limit = 6;
	
	if ( $args->theme_location != 'mainmenu' || strstr( $args->menu_class, 'mainmenu-pc-full' ) === false )
		return $sorted_menu_items;
	
	// メインメニューの項目数を6件に制限
	$unset_top_level_menu_item_ids = array();
	$array_unset_value = 1;
	$parent_count = 0;
	
	foreach ( $sorted_menu_items as $sorted_menu_item ) {

		if ( 0 == $sorted_menu_item->menu_item_parent ) {
			$parent_count++;
			if ( $parent_count > $parent_item_limit ) {
				unset( $sorted_menu_items[$array_unset_value] );
				$unset_top_level_menu_item_ids[] = $sorted_menu_item->ID;
			}
		}

		if ( in_array( $sorted_menu_item->menu_item_parent, $unset_top_level_menu_item_ids ) )
			unset( $sorted_menu_items[$array_unset_value] );

		$array_unset_value++;
	}
	
	// クラスを追加
	$class_name = 'menu-item-cols-' . ( $parent_count > $parent_item_limit ? $parent_item_limit : $parent_count );
	
	foreach ( $sorted_menu_items as $sorted_menu_item ) {
		if ( 0 == $sorted_menu_item->menu_item_parent ) {
			$sorted_menu_item->classes[] = $class_name;
		}
	}
	
	return $sorted_menu_items;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// アイキャッチ画像のデフォルトを設定

add_filter( 'post_thumbnail_html', 'nsd_default_post_thumbnail', 10, 5 );
function nsd_default_post_thumbnail( $html, $post_id, $post_thumbnail_id, $size, $attr ) {
	if ( '' === $html && ( 'post-thumbnail' === $size || 'thumbnail' === $size || 'thumbnail-small' === $size ) ) {
		if ( function_exists( 'get_field' ) ) {
			$image_id = get_field( 'nsd_site_eyecatch_default', 'option' );
			if ( $image_id ) {
				$html = wp_get_attachment_image( $image_id, $size, false, $attr );
			}
		}
	}
	
	return $html;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// excerptのカスタマイズ

// 文字数変更
add_filter( 'excerpt_length', 'nsd_excerpt_length' );

function nsd_excerpt_length( $length ) {	
	return 35;	
}	

// 末尾の文字
add_filter( 'excerpt_more', 'nsd_excerpt_more' );

function nsd_excerpt_more( $more ) {
	return '…'; 
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// テンプレート振り分け

add_filter( 'template_include', 'nsd_template_include', 99 );
function nsd_template_include( $template ) {
	if ( is_home() || is_search() && ( 'any' === get_query_var( 'post_type' ) || 'post' === get_query_var( 'post_type' ) ) ) {
		$new_template = locate_template( 'archive.php' );
		if ( '' !== $new_template )
			return $new_template;
	}

	return $template;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// アーカイブのタイトル修正

add_filter( 'wp_title', 'nsd_archive_title', 10, 3 );
function nsd_archive_title( $title, $sep, $seplocation ) {
	if ( is_date() || is_category() || is_tax() || is_search() ) {
		$new_title = '';
		
		if ( is_date() ) {
			$m = get_query_var('m');
			if ( $m ) {
				$year = substr($m, 0, 4);
				$month = intval(substr($m, 4, 2));
				$day = intval(substr($m, 6, 2));
			} else {
				$year = get_query_var('year');
				$month = get_query_var('monthnum');
				$day = get_query_var('day');
			}
			
			$new_title = wp_get_jp_archive_date();
		} elseif ( is_tax() ) {
			$new_title = single_term_title('', false);
		} elseif ( is_search() ) {
			$new_title = '検索結果 : ' . get_search_query();
		}
		
		if ( get_post_type() && ! in_array( get_post_type(), array( 'post', 'page', 'any' ) ) ) {
			$post_type_obj = get_post_type_object( get_post_type() );
			$post_type_label = $post_type_obj->label;
			
			if ( $seplocation == 'right' )
				$new_title = $title . "$post_type_label";
			else
				$new_title = "$post_type_label" . $title;
		}
		
		if ( '' !== $new_title ) {
			if ( $seplocation == 'right' )
				$title = "$new_title $sep ";
			else
				$title = " $sep $new_title";
		}
	}
	return $title;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// body_class に追加

add_filter( 'body_class', 'nsd_body_class' );
function nsd_body_class( $classes ) {
	if ( function_exists( 'get_field' ) ) {
		if ( get_field( 'nsd_front_custom_hover', 'option' ) && 'none' !== get_field( 'nsd_front_custom_hover', 'option' ) ) {
			$classes[] = 'hover-front-custom-' . esc_attr( get_field( 'nsd_front_custom_hover', 'option' ) );
		}
		
		if ( get_field( 'nsd_main_hover_post_summary', 'option' ) && 'none' !== get_field( 'nsd_main_hover_post_summary', 'option' ) ) {
			$classes[] = 'hover-post-summary-' . esc_attr( get_field( 'nsd_main_hover_post_summary', 'option' ) );
		}
	}
	
	return $classes;
}

