<?php

//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Advanced Custom Fields 設定

add_filter( 'acf/settings/path', 'nsd_acf_settings_path' );
function nsd_acf_settings_path( $path ) {
	$path = get_template_directory() . '/inc/acf/';
	return $path;
}

add_filter( 'acf/settings/dir', 'nsd_acf_settings_dir' );
function nsd_acf_settings_dir( $dir ) {
	$dir = get_template_directory_uri() . '/inc/acf/';
	return $dir;
}

$acf_plugin_activated = class_exists( 'acf' );

require_once( get_template_directory() . '/inc/acf/acf.php' );

require_once( get_template_directory() . '/inc/functions/acf-setting.php' );
if ( function_exists('acf_add_local_field_group') ) {
	foreach( apply_filters( 'nsd_custom_field_settings', $acf_settings ) as $setting ) {
		acf_add_local_field_group( $setting );
	}
}

if ( ! $acf_plugin_activated ) {
	add_filter( 'acf/settings/show_admin', '__return_false' );
	remove_filters_for_anonymous_class( 'pre_set_site_transient_update_plugins', 'acf_pro_updates', 'inject_update', 10 );
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Advanced Custom Fields のoptionフィールド バージョン互換

add_filter( 'acf/load_value', 'nsd_acf_get_option_compatibility', 8, 3 );
function nsd_acf_get_option_compatibility( $value, $post_id, $field ) {
	// nsd_header_banner はv.1.1から配列
	if ( 'nsd_header_banner' === $field['name'] && ! is_array( $value ) ) {
		$value = 'none' === $value ? array() : (array) $value;
	}
	
	return $value;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Advanced Custom Fields のoptionフィールド 未設定時にデフォルト値を取得

add_filter( 'acf/load_value', 'nsd_acf_get_option_dafault', 10, 3 );
function nsd_acf_get_option_dafault( $value, $post_id, $field ) {
	if ( null === $value && ! isset( $field['default_value'] ) ) {
		$acf_local = acf_local();
		$groups = $acf_local->groups;
		$fields = $acf_local->fields;
		
		foreach ( $fields as $item ) {
			if ( $field['name'] === $item['name'] ) {
				if ( isset( $item['default_value'] ) ) {
					if ( is_array( $item['default_value'] ) && 'select' === $item['type'] && ! $item['multiple'] ) {
						$value = array_shift( $item['default_value'] );
					} else {
						$value = $item['default_value'];
					}
				}
				break;
			}
		}
	}
	
	return $value;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Advanced Custom Fields のCSS調整

add_action( 'admin_print_styles', 'nsd_acf_print_styles' );
function nsd_acf_print_styles() {
	global $acf_settings;
?>
<style>
	.acf-settings-wrap .acf-postbox.seamless > .hndle {
		display: block;
		margin-bottom: 20px !important;
		padding-left: 0 !important;
		font-weight: normal;
		font-size: 18px !important;
	}
	
	.acf-settings-wrap .acf-postbox .hndle:hover .acf-hndle-cog {
		display: none;
	}
	
	.js .acf-settings-wrap .postbox .hndle {
		cursor: default;
	}
	
	.widget-content .acf-field {
		margin-top: 1em;
	}
	
	#acf-group_55f10b1e693db .acf-label {
		display: none;
	}
	
	.acf-fields.-left > .acf-field.acf-field-574fc27794baf > .acf-input {
		max-width: 100px;
	}
<?php
	foreach ( $acf_settings as $setting ) :
		$fields = $setting['fields'];
		
		foreach ( $fields as $field ) :
			if ( 'color_picker' === $field['type'] && '' !== $field['default_value'] ) :
				$class = '.acf-' . str_replace( '_', '-', $field['key'] );
?>
	<?php echo esc_html( $class ); ?> .wp-color-result, <?php echo esc_html( $class ); ?> .wp-color-result:focus, <?php echo esc_html( $class ); ?> .wp-color-result:hover {
		background-color: <?php echo esc_html( $field['default_value'] ); ?>;
	}
<?php
			endif;
		endforeach;
	endforeach;
?>
</style>
<?php
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// input type="number" のスクロールホイールをキャンセル (Advanced Custom Fields)

add_action( 'admin_enqueue_scripts', 'nsd_acf_scripts' );
function nsd_acf_scripts( $hook_suffix ) {
	if ( isset( $_GET['page'] ) && preg_match( '/^nyt-/', $_GET['page'] ) ) {
		wp_enqueue_script( 'ns-acf-script', esc_url( get_template_directory_uri() ) . '/js/ns-acf-script.js', array(), wp_theme_version(), true );
	}
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// テーマ設定ページ (Advanced Custom Fields)

if ( function_exists( 'acf_add_options_page' ) ) {
	acf_add_options_page( array(
		'page_title' 	=> 'テーマ設定',
		'menu_title'	=> 'テーマ設定',
		'menu_slug' 	=> 'nyt-settings',
		'capability'	=> 'edit_posts',
	) );
	
	acf_add_options_sub_page( array(
		'page_title' 	=> 'サイト設定',
		'menu_title'	=> 'サイト設定',
		'menu_slug'		=> 'nyt-site',
		'parent_slug'	=> 'nyt-settings',
	) );
	
	acf_add_options_sub_page( array(
		'page_title' 	=> '表示設定',
		'menu_title'	=> '表示設定',
		'menu_slug'		=> 'nyt-reading',
		'parent_slug'	=> 'nyt-settings',
	) );
	
	acf_add_options_sub_page( array(
		'page_title' 	=> 'フロントページ設定',
		'menu_title'	=> 'フロントページ',
		'menu_slug'		=> 'nyt-front-page',
		'parent_slug'	=> 'nyt-settings',
	) );
	
	acf_add_options_sub_page( array(
		'page_title' 	=> '投稿設定',
		'menu_title'	=> '投稿設定',
		'menu_slug'		=> 'nyt-post',
		'parent_slug'	=> 'nyt-settings',
	) );
	
	acf_add_options_sub_page( array(
		'page_title' 	=> 'CTA設定',
		'menu_title'	=> 'CTA設定',
		'menu_slug'		=> 'nyt-cta',
		'parent_slug'	=> 'nyt-settings',
	) );	
}

