<?php

//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー カスタム投稿タイプ設定

add_action( 'init', 'nsd_register_faq_post_type' );

function nsd_register_faq_post_type() {
	register_post_type(
		'faq',
		array(
			'label'			=> 'FAQ',
			'labels'		=> array(
									'edit_item' 	=> 'FAQを編集',
									'add_new_item'	=> '新規FAQを追加',
								),
			'public'		=> false,
			'show_ui'		=> true,
			'has_archive'	=> false,
			'rewrite'		=> array( 'with_front' => false ),
			'menu_position'	=> 5,
			'supports'		=> array( 'title', 'editor' ),
			'taxonomies'	=> array( 'faq_cat' ),
		)
	);
	
	register_taxonomy(
		'faq_cat',
		'faq',
		array(
			'label'			=> 'FAQカテゴリー',
			'public'		=> false,
			'show_ui'		=> true,
			'meta_box_cb'	=> false,
		)
	);
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー 作成ページ

// 「順序」カラム追加
add_filter( 'manage_edit-faq_cat_columns', 'nsd_faq_cat_add_column' );
function nsd_faq_cat_add_column( $columns ) {
	if ( isset( $columns['cb'] ) )
		$columns_custom['cb'] = $columns['cb'];
	if ( isset( $columns['name'] ) )
		$columns_custom['name'] = $columns['name'];
	if ( isset( $columns['description'] ) )
		$columns_custom['description'] = $columns['description'];
	
	$columns_custom['term_order'] = '順序';
	
	if ( isset( $columns['posts'] ) )
		$columns_custom['posts'] = $columns['posts'];
	
	return $columns_custom;
}

// 「順序」カラムを並び替え対象に設定
add_filter( 'manage_edit-faq_cat_sortable_columns', 'nsd_faq_cat_sortable_columns' );
function nsd_faq_cat_sortable_columns( $columns ) {
	$columns['term_order'] = 'term_order';
	return $columns;
}

// 「順序」カラムを表示
add_action( 'manage_faq_cat_custom_column', 'nsd_faq_cat_display_column', 10, 3 );
function nsd_faq_cat_display_column( $column, $column_name, $term_id ) {
	if ( 'term_order' === $column_name ) {
		$term = get_term( $term_id, 'faq_cat' );
		
		if ( isset( $term->term_order ) && $term->term_order && 999 != $term->term_order ) {
			echo esc_html( $term->term_order );
		}
	}
}

// term_order で並べ替え表示
add_action( 'pre_get_posts', 'nsd_faq_cat_columns_orderby' );
function nsd_faq_cat_columns_orderby( $query ) {
	if( ! is_admin() )  
		return;
	
	$orderby = $query->get( 'orderby' );  
	
	if ( in_array( $orderby, array( 'term_order' ) ) ) {  
		$query->set( 'orderby','term_order' );  
	}	
}

// フォームに「順序」フィールドを表示
add_action( 'faq_cat_add_form_fields', 'nsd_faq_cat_add_form_fields' );
function nsd_faq_cat_add_form_fields() {
?>
<div class="form-field term-term_order-wrap">
	<label for="tag-term_order">順序</label>
	<input name="term_order" id="tag-term_order" type="number" value="" size="10">
</div>
<?php
}

// ターム作成時に term_order を追加
add_action( 'create_faq_cat', 'nsd_faq_cat_create_faq_cat', 10, 2 );
function nsd_faq_cat_create_faq_cat( $term_id, $tt_id ) {
	if ( isset( $_POST['term_order'] ) && isset( $_POST['_wpnonce_add-tag'] ) ) {
		check_admin_referer( 'add-tag', '_wpnonce_add-tag' );
		
		nsd_update_faq_term_order( $_POST['term_order'], $term_id );
	}
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー 編集ページ

// フォームに「順序」フィールドを表示
add_action( 'faq_cat_edit_form_fields', 'nsd_faq_cat_edit_form_fields' );
function nsd_faq_cat_edit_form_fields( $term ) {
	$term_order_value = isset( $term->term_order ) && ( $term->term_order > 0 ) && ( 999 != $term->term_order ) ? $term->term_order : '';
?>
<tr class="form-field term-term_order-wrap">
	<th scope="row"><label for="term_order">順序</label></th>
	<td>
		<input name="term_order" id="term_order" type="number" value="<?php echo esc_attr( $term_order_value ); ?>" size="10">
	</td>
</tr>
<?php
}

// ターム変更時に term_order の変更を反映
add_action( 'edit_faq_cat', 'nsd_faq_cat_edit_faq_cat', 10, 2 );
function nsd_faq_cat_edit_faq_cat( $term_id, $tt_id ) {
	if ( isset( $_POST['term_order'] ) && 'editedtag' === $_POST['action'] ) {
		check_admin_referer( 'update-tag_' . $term_id );
		
		nsd_update_faq_term_order( $_POST['term_order'], $term_id );
	}
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー CSS

add_action( 'admin_print_styles', 'nsd_faq_cat_print_styles' );
function nsd_faq_cat_print_styles() {
?>
<style>
	.taxonomy-faq_cat #tag-term_order, .taxonomy-faq_cat #term_order {
		max-width: 100px;
	}
</style>
<?php
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー Javascript

add_action( 'admin_footer', 'nsd_faq_cat_edit_script' );
function nsd_faq_cat_edit_script() {
	$screen = get_current_screen();
	
	if ( 'edit-faq_cat' === $screen->id ) :
?>
<script type="text/javascript">
(function($) {
	$(document).ajaxComplete(function(event, xhr, settings) {
		var hashes = settings.data.split("&");
		if ( $.inArray( "action=add-tag", hashes ) != -1 ) {
			$("#tag-term_order").val("");
		}
	});
})(jQuery);
</script>
<?php
	endif;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー 並べ替え

// orderby => term_order に対応
add_filter( 'get_terms_orderby', 'nsd_faq_cat_terms_orderby', 1, 2 );
function nsd_faq_cat_terms_orderby( $orderby, $args ) {
	if ( isset( $args['orderby'] ) && $args['orderby'] == 'term_order' && $orderby != 'term_order' )
		return 't.term_order';
	
	return $orderby;
}

// 管理画面で orderby が name (デフォルト値) の場合、term_order に変更
add_filter( 'get_terms_args', 'nsd_faq_cat_terms_args', 10, 2 );
function nsd_faq_cat_terms_args( $args, $taxonomies ) {
	if ( is_admin() && 1 === count( $taxonomies ) && 'faq_cat' === array_shift( $taxonomies ) ) {
		if ( 'name' === $args['orderby'] && ! isset( $_REQUEST['orderby'] ) ) {
			$args['orderby'] = 'term_order';
		}
	}
	
	return $args;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー 関数

function nsd_update_faq_term_order( $term_order, $term_id ) {
	global $wpdb;
	
	$term_order = preg_match( '/^\d*$/mu', $term_order ) && $term_order ? (int) $term_order : 999;
	return $wpdb->update( $wpdb->terms, array( 'term_order' => $term_order ), array( 'term_id' => $term_id ) );
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// FAQカテゴリー 更新メッセージ

add_filter( 'post_updated_messages', 'nsd_faq_post_updated_messages' );
function nsd_faq_post_updated_messages( $messages ) {
	$messages['faq'] = array(
		0 => '',
		1 => 'FAQを更新しました。',
		2 => 'FAQを更新しました。',
		3 => 'FAQを削除しました。',
		4 => 'FAQを更新しました。',
		5 => false,
		6 => 'FAQを公開しました。',
		7 => 'FAQを保存しました。',
		8 => 'FAQを承認しました。',
		9 => 'FAQを公開予約しました。',
		10 => 'FAQの下書きを更新しました。'
	);
	
	return $messages;
}

