<?php

//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// CSS, Javascript

add_action( 'wp_enqueue_scripts', 'nsd_enqueue_scripts' );
if ( ! function_exists( 'nsd_enqueue_scripts' ) ) {
	function nsd_enqueue_scripts() {
		wp_enqueue_style( 'ns-common', esc_url( get_template_directory_uri() ) . '/css/ns-common.css', array(), wp_theme_version() );
		
		if ( 'front-page' === nsd_get_template_name() && 'full' === nsd_firstview() && have_rows( 'nsd_front_slider', 'option' ) )
		wp_enqueue_style( 'style-full', esc_url( get_template_directory_uri() ) . '/css/firstview-full.css', array( 'ns-common' ), wp_theme_version() );
		
		wp_enqueue_style( 'bxslider', esc_url( get_template_directory_uri() ) . '/css/jquery.bxslider.css', array(), '4.2.5' );
		wp_enqueue_script( 'bxslider', esc_url( get_template_directory_uri() ) . '/js/jquery.bxslider.min.js', array('jquery'), '4.2.5' );
		
		if ( get_field( 'nsd_sidebar_fix', 'option' ) )
			wp_enqueue_script( 'theia-sticky-sidebar', esc_url( get_template_directory_uri() ) . '/js/theia-sticky-sidebar.js', array('jquery'), '4.2.5' );
		
		wp_enqueue_script( 'site', esc_url( get_template_directory_uri() ) . '/js/site.js', array( 'jquery', 'bxslider' ), '1.5.0' );
		
		wp_localize_script( 'site', 'NSTheme', array(
			'bxslider' => array(
				'pause' => '' === get_field( 'nsd_front_slider_pause', 'option' ) ? 4000 : get_field( 'nsd_front_slider_pause', 'option' ) * 1000,
				'touchEnabled' => 'vertical' === get_field( 'nsd_front_slider_sp_size', 'option' ) ? false : true,
			),
		) );
	}
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// カスタマイズCSS

add_action( 'wp_head', 'nsd_customize_css' );
function nsd_customize_css() {
	global $brightness_threshold;
	
	if ( function_exists( 'get_field' ) ) {
		$font_color = get_field( 'nsd_main_font_color', 'option' ) ? get_field( 'nsd_main_font_color', 'option' ) : '#666666';
		
		$header_bg_color = get_field( 'nsd_header_bg_color', 'option' ) ? get_field( 'nsd_header_bg_color', 'option' ) : '';
		$header_menu_bg_color = nsd_header_menu_bg_color();
		$header_menu_text_color = get_field( 'nsd_header_menu_text_color', 'option' ) ? get_field( 'nsd_header_menu_text_color', 'option' ) : '';
		$main_bg_color = get_field( 'nsd_main_bg_color', 'option' ) ? get_field( 'nsd_main_bg_color', 'option' ) : '';
		
		$main_label_color = get_field( 'nsd_main_label_color', 'option' ) ? get_field( 'nsd_main_label_color', 'option' ) : '';
		$main_label_text_color = $main_label_color ? ( nsd_get_brightness( $main_label_color ) > $brightness_threshold ? $font_color : '#ffffff' ) : '';
		
		$main_title_style = get_field( 'nsd_main_title_style', 'option' ) ? get_field( 'nsd_main_title_style', 'option' ) : 'simple';
		$main_title_color = get_field( 'nsd_main_title_color', 'option' ) ? get_field( 'nsd_main_title_color', 'option' ) : '#d1ae6e';
		
		$main_button_color = get_field( 'nsd_main_button_color', 'option' ) ? get_field( 'nsd_main_button_color', 'option' ) : '';
		$main_button_text_color = $main_button_color ? ( nsd_get_brightness( $main_button_color ) > $brightness_threshold ? $font_color : '#ffffff' ) : '';
		
		$footer_bg_color = get_field( 'nsd_footer_bg_color', 'option' ) ? get_field( 'nsd_footer_bg_color', 'option' ) : '';
		
		$post_content_font_size = get_field( 'nsd_main_post_font_size', 'option' ) ? intval( get_field( 'nsd_main_post_font_size', 'option' ) ) : 16;
		$post_content_margin = round( $post_content_font_size * 1.5 );
		
		$custom_css = get_field( 'nsd_custom_css', 'option' );
?>
<style>
<?php if ( $header_bg_color ) : ?>
	<?php if ( 'front-page' === nsd_get_template_name() && 'full' === nsd_firstview() && have_rows( 'nsd_front_slider', 'option' ) ) : ?>
@media screen and (max-width: 568px) {
	#header, .mainmenu-pc-short > li > ul  {
		background-color: <?php echo esc_html( $header_bg_color ); ?>;
	}
}
	<?php else : ?>
#header, .mainmenu-pc-short > .menu-item > ul {
	background-color: <?php echo esc_html( $header_bg_color ); ?>;
}
	<?php endif; ?>
<?php endif; ?>

<?php if ( $header_menu_bg_color ) : ?>
.header-menu-color, .header-menu-color .sub-menu, .header-menu-color .children {
	background-color: <?php echo esc_html( $header_menu_bg_color ); ?>;
}
<?php endif; ?>

<?php if ( $header_menu_text_color ) : ?>
.header-menu-text-color {
	color: <?php echo esc_html( $header_menu_text_color ); ?>;
}

.header-menu-text-color .mainmenu-pc-short a:hover, .header-menu-text-color .mainmenu-pc-short a:active {
	color: inherit;
	opacity: 0.8;
}

.header-menu-text-color .mainmenu-pc-short > .menu-item-has-children a:hover, .header-menu-text-color .mainmenu-pc-short > .menu-item-has-children a:active {
	opacity: 1;
}

.mainmenu-pc-full > li:first-child:before, .mainmenu-pc-full > li:after, .mainmenu-pc-full .sub-menu > li + li:before, .mainmenu-pc-full .children > li + li:before {
	background-color: <?php echo esc_html( $header_menu_text_color ); ?>;
}

.mainmenu-sp > li, .mainmenu-pc-full .sub-menu, .mainmenu-pc-full .children, .mainmenu-sp .sub-menu, .mainmenu-sp .children {
	border-color: <?php echo esc_html( $header_menu_text_color ); ?>;
}
<?php endif; ?>

<?php if ( $main_bg_color ) : ?>
#content {
	background-color: <?php echo esc_html( $main_bg_color ); ?>;
}
<?php endif; ?>

<?php if ( $main_label_color ) : ?>
.label-color {
	color: <?php echo esc_html( $main_label_text_color ); ?>;
	background-color: <?php echo esc_html( $main_label_color ); ?>;
}
<?php endif; ?>

.title-color, .comment-content h1, .comment-content h2, .comment-content h3 {
	color: <?php echo esc_html( $main_title_color ); ?>;
}

<?php if ( 'simple' === $main_title_style ) : ?>
	.post-content h1, .post-content h2, .post-content h3 {
		color: <?php echo esc_html( $main_title_color ); ?>;
	}
<?php elseif ( 'left_border' === $main_title_style ) : ?>
	.post-content h1, .post-content h2, .post-content h3 {
		padding-left: 14px;
		border-left-width: 2px;
		border-left-style: solid;
	}
	
	.post-content h1, .post-content h2 {
		border-left-color: <?php echo esc_html( $main_title_color ); ?>;
	}
	
	.post-content h3 {
		border-left-color: #999999;
	}
<?php endif; ?>

<?php if ( $main_button_color ) : ?>
.button-color, .button-color:hover, .button-color:active,
.post-content .button-color, .post-content .button-color:hover, .post-content .button-color:active,
.text-white .button-color, .text-white .button-color:hover, .text-white .button-color:active,
.text-gray .button-color, .text-gray .button-color:hover, .text-gray .button-color:active {
	color: <?php echo esc_html( $main_button_text_color ); ?>;
	background-color: <?php echo esc_html( $main_button_color ); ?>;
}

.ns-button-color, .ns-button-color:hover, .ns-button-color:active {
	background-color: <?php echo esc_html( $main_button_color ); ?>;
}

a.ns-button-color, a.ns-button-color:hover, a.ns-button-color:active {
	color: <?php echo esc_html( $main_button_text_color ); ?>;
}
<?php endif; ?>

<?php if ( $footer_bg_color ) : ?>
#footer {
	background-color: <?php echo esc_html( $footer_bg_color ); ?>;
}
<?php endif; ?>

body, .footer-widgets .widget {
	color : <?php echo esc_html( $font_color ); ?>;
}

.post-content-main, .comment-content {
	font-size: <?php echo esc_html( $post_content_font_size ); ?>px;
}

.post-content-main p, .post-content-main div, .post-content-main ul, .post-content-main dl, .post-content-main ol, .post-content-main blockquote, .post-content-main table, .post-content-main pre, .post-content-main figure, .comment-content p, .comment-content div, .comment-content ul, .comment-content dl, .comment-content ol, .comment-content blockquote, .comment-content table, .comment-content pre, .comment-content figure {
	margin-top: <?php echo esc_html( $post_content_margin ); ?>px;
	margin-bottom: <?php echo esc_html( $post_content_margin ); ?>px;
}

.post-content h1, .post-content h2, .post-content h3, .post-content h4, .post-content h5, .post-content h6, .comment-content h1, .comment-content h2, .comment-content h3, .comment-content h4, .comment-content h5, .comment-content h6 {
	margin-top: <?php echo esc_html( $post_content_margin * 2 ); ?>px;
	margin-bottom: <?php echo esc_html( $post_content_margin ); ?>px;
}
<?php
	$item_index = 1;
	while ( have_rows( 'nsd_front_slider', 'option' ) ) {
		the_row();
		$image = wp_get_attachment_image_src( get_sub_field( 'image' ), 'full' );
		$image_url = $image[0];
?>
#slider li.item-<?php echo esc_html( $item_index ); ?> {
	background-image: url(<?php echo esc_url( $image_url ); ?>);
}
<?php
		$image_sp = wp_get_attachment_image_src( get_sub_field( 'image_sp' ), 'page-eyecatch' );
		
		if ( ! isset( $image_sp[0] ) ) {
			$image_sp = wp_get_attachment_image_src( get_sub_field( 'image' ), 'page-eyecatch' );
		}
		
		$image_sp_url = $image_sp[0];
?>
@media screen and (max-width: 568px) {
	#slider li.item-<?php echo esc_html( $item_index ); ?> {
		background-image: url(<?php echo esc_url( $image_sp_url ); ?>);
	}
}
<?php
		$item_index ++;
	}
?>
<?php if ( $custom_css ) echo esc_html( $custom_css ); ?>
</style>
<?php
	}
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// ビジュアルエディタのカスタマイズCSS

add_filter( 'mce_css', 'nsd_add_custom_editor_style' );
function nsd_add_custom_editor_style( $mce_css ) {
	if ( ! empty( $mce_css ) )
		$mce_css .= ',';

	$mce_css .= add_query_arg( 'action', 'nsd_custom_editor_style', admin_url( 'admin-ajax.php' ) );

	return $mce_css;
}

add_action( 'wp_ajax_nsd_custom_editor_style', 'nsd_custom_editor_style_callback' );
add_action( 'wp_ajax_nopriv_nsd_custom_editor_style', 'nsd_custom_editor_style_callback' );
function nsd_custom_editor_style_callback() {
	global $brightness_threshold;
	
	$font_color = get_field( 'nsd_main_font_color', 'option' ) ? get_field( 'nsd_main_font_color', 'option' ) : '#666666';
	$post_content_font_size = get_field( 'nsd_main_post_font_size', 'option' ) ? intval( get_field( 'nsd_main_post_font_size', 'option' ) ) : 16;
	$post_content_margin = round( $post_content_font_size * 1.5 );
	$post_content_margin_2x = $post_content_margin * 2;
	$main_title_style = get_field( 'nsd_main_title_style', 'option' ) ? get_field( 'nsd_main_title_style', 'option' ) : 'simple';
	$main_title_color = get_field( 'nsd_main_title_color', 'option' ) ? get_field( 'nsd_main_title_color', 'option' ) : '#d1ae6e';
	$main_button_color = get_field( 'nsd_main_button_color', 'option' ) ? get_field( 'nsd_main_button_color', 'option' ) : '';
	$main_button_text_color = $main_button_color ? ( nsd_get_brightness( $main_button_color ) > $brightness_threshold ? $font_color : '#ffffff' ) : '';
	
	header( 'Content-Type: text/css' );
	
	echo "body { color: {$font_color}; font-size: {$post_content_font_size}px; }\n";
	echo "body p, body div, body ul, body dl, body ol, body blockquote, body table, body pre, body figure { margin-top: {$post_content_margin}px; margin-bottom: {$post_content_margin}px; }\n";
	echo "body h1, body h2, body h3, body h4, body h5, body h6 { margin-top: {$post_content_margin_2x}px; margin-bottom: {$post_content_margin}px; }\n";
	
	if ( 'simple' === $main_title_style ) {
		echo "body h1, body h2, body h3 { color: {$main_title_color}; }\n";
	} elseif ( 'left_border' === $main_title_style ) {
		echo "body h1, body h2, body h3 { padding-left: 14px; border-left-width: 2px; border-left-style: solid; }\n";
		echo "body h1, body h2 { border-left-color: {$main_title_color}; }\n";
		echo "body h3 { border-left-color: #999999; }\n";
	}
	
	if ( $main_button_color )
		echo ".ns-button-color, .ns-button-color:hover, .ns-button-color:active { background-color: {$main_button_color}; }\n";
		echo "a.ns-button-color, a.ns-button-color:hover, a.ns-button-color:active { color: {$main_button_text_color}; }\n";
	
	die();
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// スマートフォン表示では管理バーを非表示

add_action( 'wp_footer', 'nsd_wp_footer_style', 99 );
function nsd_wp_footer_style() {
	if ( is_user_logged_in() ) :
?>
<style>
	@media screen and (max-width: 568px) {
		html {
			margin-top: 0 !important;
		}
		
		#wpadminbar {
			display: none;
		}
	}
</style>
<?php
	endif;
}


//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// カスタマイザー対応CSS

add_action( 'admin_print_styles', 'nsd_customize_print_styles' );
function nsd_customize_print_styles() {
?>
<style>
	#accordion-panel-widgets {
		display: none !important;
	}
	
	.widgets-php .hide-if-no-customize {
		display: none;
	}
</style>
<?php
}

