<?php

// autop前に処理するショートコード
add_filter( 'the_content', 'nsd_run_shortcode_before_wpautop', 9 );
function nsd_run_shortcode_before_wpautop( $content ) {
	global $shortcode_tags;
	
	$orig_shortcode_tags = $shortcode_tags;
	remove_all_shortcodes();
	
	add_shortcode( 'ns_row', 'nsd_shortcode_row' );
	add_shortcode( 'ns_col', 'nsd_shortcode_col' );
	add_shortcode( 'ns_button', 'nsd_shortcode_button' );
	add_shortcode( 'ns_table', 'nsd_shortcode_table' );
	
	$content = do_shortcode( $content );
	
	$shortcode_tags = $orig_shortcode_tags;
	
	return $content;
}

// カラムレイアウト
function nsd_shortcode_row( $atts, $content = null ) {
	extract( shortcode_atts( array(
			'cols'	=> 0,
			'id'	=> '',
			'class'	=> '',
		), $atts ) );
	
	$content = do_shortcode( $content );
	
	// cols の自動計算
	if ( ! $cols ) {
		preg_match_all( '/<div[^>]*ns-col-(\d+)[^>]*>/', $content, $matches );
		$cols = array_sum( $matches[1] );
	}
	
	return '<div' . ( '' !== $id ? ' id="' . esc_attr( $id ) . '"' : '' ) . ' class="ns-row ns-row-' . esc_attr( $cols ) . ' ' . $class . '">' . $content . '</div>';
}

function nsd_shortcode_col( $atts, $content = null ) {
	extract( shortcode_atts( array(
			'cols'	=> 0, // v.1.5
			'size'	=> 0, // v.1.1
			'id'	=> '',
			'class'	=> '',
		), $atts ) );
	
	// cols = size (v.1.5)
	$cols = $cols ? $cols : ( $size ? $size : 1 );
	
	$content = preg_replace( '/^(?:\r\n|\n)*/', "\n\n", $content );
	$content = preg_replace( '/([^\r\n])(?:\r\n|\n)*$/', "$1\n\n", $content );
		
	return '<div' . ( '' !== $id ? ' id="' . esc_attr( $id ) . '"' : '' ) . ' class="ns-col ns-col-' . esc_attr( $cols ) . ' ' . $class . '">' . do_shortcode( $content ) . '</div>';
}

// ボタン
function nsd_shortcode_button( $atts, $content = null ) {
	global $brightness_threshold;
	
	extract( shortcode_atts( array(
			'href'		=> '',
			'target'	=> '',
			'color'		=> 'color',
			'size'		=> 'large',
			'width'		=> '',
			'class'		=> '',
		), $atts ) );
	
	$button_class = 'ns-button';
	$style = '';
	
	if ( 'gray' === $color ) {
		$button_class .= ' ns-button-gray';
	} elseif ( preg_match( '/^#(?:[0-9A-F]{3}|[0-9A-F]{6})$/i', $color ) ) {
		$style = 'color: ' . ( nsd_get_brightness( $color )  > $brightness_threshold ? '#666666' : '#ffffff' ) . ';';
		$style .= 'background-color: ' . $color . ';';
		$button_class .= ' ns-button-custom-color';
	} else {
		$button_class .= ' button-color';
	}
	
	if ( $width ) {
		$style .= 'width: ' . $width . ';';
	}
	
	if ( in_array( $size, array( 'small', 'medium', 'large' ) ) ) {
		$button_class .= ' ns-button-' . $size;
	}
	
	if ( $class ) {
		$button_class .= ' ' . $class;
	}
	
	return '<a href="' . esc_url( $href ) . '"' . ( $target ? ' target="' . esc_attr( $target ) . '"' : '' ) . ' class="' . esc_attr( $button_class ) . '"' . ( $style ? ' style="' . esc_attr( $style ) . '"' : '' ) . '>' . do_shortcode( $content ) . '</a>';
}

// テーブル
function nsd_shortcode_table( $atts, $content = null ) {
	extract( shortcode_atts( array(
			'type'		=> 'col',
		), $atts ) );
	
	return '<div class="ns-' . esc_attr( $type ) . '-table">' . do_shortcode( $content ) . '</div>';
}

