<?php

// テーマのバージョン
function wp_theme_version( $parent = true ) {
	if ( $parent ) {
		$theme = wp_get_theme( 'new-standard-2' );
	}
	
	if ( ! $parent || ! $theme->exists() ) {
		$theme = wp_get_theme();
	}
	
	return $theme->get( 'Version' );
}


// 投稿ページのURL
function wp_get_posts_page_url() {
	if ( get_option( 'show_on_front' ) == 'page' && get_option( 'page_for_posts' ) ) {
		$posts_page_id = get_option( 'page_for_posts' );
		return get_permalink( $posts_page_id );
	} else {
		return '';
	}
}


// アーカイブページの日付
function wp_get_jp_archive_date() {
	$m = get_query_var( 'm' );
	if ( $m ) {
		$year = substr( $m, 0, 4 );
		$month = intval( substr( $m, 4, 2 ) );
		$day = intval( substr( $m, 6, 2 ) );
	} else {
		$year = get_query_var( 'year' );
		$month = get_query_var( 'monthnum' );
		$day = get_query_var( 'day' );
	}
	
	return ( $year ? $year . '年' : '' ) . ( $month ? $month . '月' : '' ) . ( $day ? $day . '日' : '' );
}


// 背景色から文字色を返す
function nsd_text_color_class( $bg_color, $echo = true ) {
	global $brightness_threshold;
	
	$class = '';
	
	if ( $bg_color ) {
		$bright = nsd_get_brightness( $bg_color );
		if ( $bright )
			$class = $bright > $brightness_threshold ? 'text-gray' : 'text-white';
	}
	
	if ( $echo )
		echo $class;
	else
		return $class;
}


// 色の明るさを計算
function nsd_get_brightness( $color ) {
	if( substr( $color, 0, 1 ) != "#" )
		return false;
	
	if( strlen( $color ) == 7 ) {
		$r = hexdec( substr( $color, 1, 2 ) );
		$g = hexdec( substr( $color, 3, 2 ) );
		$b = hexdec( substr( $color, 5, 2 ) );
	} elseif( strlen( $color ) == 4 ) {
		$r = substr( $color, 1, 1 );
		$g = substr( $color, 2, 1 );
		$b = substr( $color, 3, 1 );
		$r = hexdec( $r . $r );
		$g = hexdec( $g . $g );
		$b = hexdec( $b . $b );
	}
	
	$bright = ( ( $r * 299 ) + ( $g * 587 ) + ( $b * 114 ) ) / 1000;
	
	return $bright;
}


// メニュー未設定時の表示
function nsd_nav_fallback( $args ) {
	$menu_id = ( isset( $args['menu_id'] ) && '' !== $args['menu_id'] ) ? $args['menu_id'] : '';
	$menu_class = ( isset( $args['menu_class'] ) && '' !== $args['menu_class'] ) ? $args['menu_class'] : '';
	$page_menu = wp_page_menu(
		array(
			'echo' => false,
			'link_before' => '<span>',
			'link_after' => '</span>',
			'container' => '',
			'before' => '',
			'after' => '',
		)
	);
	$page_menu = preg_replace( '/^<div[^>]*>(.*)<\/div>$/mu', '$1', $page_menu );
	$page_menu = preg_replace( '/(<li [^>]*class="[^"]*)page_item_has_children/', '$1menu-item-has-children', $page_menu );
	$page_menu = preg_replace( '/(<li [^>]*class="[^"]*)current_page_item/', '$1current-menu-item', $page_menu );
	$page_menu = preg_replace( '/(<li [^>]*class="[^"]*)page_item/', '$1menu-item', $page_menu );
	
	$nav_menu = sprintf( $args['items_wrap'], esc_attr( $menu_id ), esc_attr( $menu_class ), $page_menu );
	$nav_menu = str_replace( ' id=""', '', $nav_menu );
	
	echo $nav_menu;
}


// パンくず
function nsd_breadcrumb() {
	global $post, $paged;
	
	$items = array();
	
	// トップページ
	$items[] = array(
			'title' => 'TOP',
			'url'	=> home_url(),
		);
	
	// 投稿タイプ
	$post_type = '';
	
	if ( is_singular() ) {
		$post_type = get_post_type();
	} else {
		$post_type = get_query_var( 'post_type' );
		
		if ( ! $post_type ) {
			if ( is_home() || is_category() || is_tag() || is_date() || is_author() ) {
				$post_type = 'post';
			}
		}
	}
	
	if ( $post_type ) {
		if ( 'post' === $post_type && wp_get_posts_page_url() ) {
			$items[] = array(
				'title' => 'BLOG',
				'url' => wp_get_posts_page_url(),
			);
		} elseif ( ! in_array( $post_type, array( 'post', 'page', 'attachment', 'any' ) ) ) {
			$post_type_obj = get_post_type_object( $post_type );
			$items[] = array(
				'title' => $post_type_obj->label,
				'url' => get_post_type_archive_link( $post_type_obj->name ),
			);
		}
	}
	
	// 日付・タクソノミー・検索結果
	if ( is_date() ) {
		$items[] = array(
			'title' => wp_get_jp_archive_date()
		);
	} elseif ( is_search() ) {
		$items[] = array(
			'title' => '検索結果 : ' . get_search_query(),
		);
	} elseif ( is_author() ) {
		$items[] = array(
			'title' => get_queried_object()->data->display_name
		);
	} elseif ( is_category() || ( is_single() && 'post' === $post_type ) ) {
		if ( is_category() ) {
			$category = get_queried_object();
		} else {
			$categories = get_the_category();
			$category = array_shift( $categories );
		}
		
		if ( $category->parent ) {
			$ancestor_ids = get_ancestors( $category->term_id, 'category' );
			$ancestor_ids = array_reverse( $ancestor_ids );
			
			foreach ( $ancestor_ids as $ancestor_id ) {
				$ancestor = get_category( $ancestor_id );
				$items[] = array(
					'title' => $ancestor->name,
					'url' => get_category_link( $ancestor )
				);
			}
		}
		
		$items[] = array(
			'title' => $category->name,
			'url' => get_category_link( $category )
		);
	} elseif ( is_tag() ) {
		$items[] = array(
			'title' => single_tag_title('', false)
		);
	} elseif ( is_tax() ) {
		$items[] = array(
			'title' => single_term_title('', false)
		);
	}
	
	// ページング
	if ( is_paged() ) {
		$items[] = array(
			'title' => 'ページ' . $paged
		);
	}
	
	// 個別ページ
	if ( is_singular() ) {
		$post_type_obj = get_post_type_object( $post_type );
		
		if ( $post_type_obj->hierarchical ) {
			$ancestors = get_post_ancestors( $post );
			
			if ( count( $ancestors ) ) {
				$ancestors = array_reverse( $ancestors );
				foreach ( $ancestors as $ancestor_id ) {
					$items[] = array(
						'title' => get_the_title( $ancestor_id ),
						'url' => get_permalink( $ancestor_id )
					);
				}
			}
		}
		
		$items[] = array(
			'title' => get_the_title( $post )
		);
	}
	
	if ( 1 === count( $items ) ) {
		$items[] = array(
			'title' => esc_html( trim( wp_title( '', false ) ) )	
		);
	}
	
	// 最後のアイテムのリンクを無効にする
	if ( count( $items ) ) {
		$last_item = array_pop( $items );
		if ( isset( $last_item['url'] ) )
			unset( $last_item['url'] );
		array_push( $items, $last_item );
	}
	
	return $items;
}


// コメントの「過去のコメント」「新しいコメント」
function nsd_comment_nav() {
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>
	<nav class="navigation comment-navigation" role="navigation">
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( '過去のコメント' ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( '新しいコメント' ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}


// ページナビ
function nsd_pagination( $pages = '', $range = 2 ) {  
	$showitems = ( $range * 2 ) + 1;  
	
	global $paged;
	if ( empty( $paged ) ) $paged = 1;
	
	if( $pages == '' ) {
		global $wp_query;
		$pages = $wp_query->max_num_pages;
		if ( ! $pages ) {
			$pages = 1;
		}
	}   
	
	if ( 1 != $pages ) {
		echo '<div class="pagination">';
		echo ( $paged > 1 ) ? '<a href="' . get_pagenum_link( $paged - 1 ) . '" class="sp-prev">&lt; BACK</a>' : '<span class="sp-prev disabled">&lt; BACK</span>';
		echo '<span class="paged">PAGE ' . $paged . ' / ' . $pages . '</span>';
		echo ( $paged < $pages ) ? '<a href="' . get_pagenum_link( $paged + 1 ) . '" class="sp-next">NEXT &gt;</a>' : '<span class="sp-next disabled">NEXT &gt;</span>';
		if ( $paged > 2 && $paged > $range + 1 && $showitems < $pages ) echo '<a href="' . get_pagenum_link( 1 ) . '" class="first">&laquo;</a>';
		if ( $paged > 1 && $showitems < $pages ) echo '<a href="' . get_pagenum_link( $paged - 1 ) . '" class="prev">&lsaquo;</a>';
		
		for ( $i = 1; $i <= $pages; $i++ ) {
			if ( 1 != $pages && ( !( $i >= $paged+$range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo ( $paged == $i ) ? '<span class="pagenum current">' . $i . '</span>' : '<a href="' . get_pagenum_link( $i ) . '" class="pagenum inactive">' . $i . '</a>';
			}
		}
		
		if ( $paged < $pages && $showitems < $pages ) echo '<a href="' . get_pagenum_link( $paged + 1 ) . '" class="next">&rsaquo;</a>';  
		if ( $paged < $pages - 1 &&  $paged + $range - 1 < $pages && $showitems < $pages ) echo '<a href="' . get_pagenum_link( $pages ) . '" class="last">&raquo;</a>';
		echo '</div>' . "\n";
	}
}


// テーマの初期設定
function nsd_optional_setup() {
	// posts_per_page 設定
	if ( 10 == get_option( 'posts_per_page', 10 ) ) {
		update_option( 'posts_per_page', 12 );
	}
	
	// フロントページ・投稿ページ設定
	if ( 'page' !== get_option( 'show_on_front', 'posts' ) ) {
		update_option( 'show_on_front', 'page' );
		
		// フロントページ
		$front_page = get_page_by_path( 'front-page' );
		
		if ( $front_page ) {
			$front_page_id = $front_page->ID;
		} else {
			$front_page_id = wp_insert_post( array(
					'post_name'		=> 'front-page',
					'post_title'	=> 'フロントページ',
					'post_status'	=> 'publish',
					'post_type'		=> 'page',
					'menu_order'	=> 1,
				) );
		}
		
		if ( $front_page_id )
			update_option( 'page_on_front', $front_page_id );
		
		// 投稿ページ
		$blog_page = get_page_by_path( 'blog' );
		
		if ( $blog_page ) {
			$page_for_posts_id = $blog_page->ID;
		} else {
			$page_for_posts_id = wp_insert_post( array(
					'post_name'		=> 'blog',
					'post_title'	=> 'ブログ',
					'post_status'	=> 'publish',
					'post_type'		=> 'page',
					'menu_order'	=> 2,
				) );
		}
		
		if ( $page_for_posts_id )
			update_option( 'page_for_posts', $page_for_posts_id );
	}
	
	// 商品一覧ページ作成
	$items_page = get_page_by_path( 'items' );
	if ( $items_page ) {
		$items_id = $items_page->ID;
	} else {
		$items_id = wp_insert_post( array(
				'post_name'		=> 'items',
				'post_title'	=> '商品一覧',
				'post_status'	=> 'publish',
				'post_type'		=> 'page',
				'menu_order'	=> 3,
				'page_template'	=> 'page-template-baseshop.php',
			) );
	}
	
	// FAQページ作成
	$faq_page = get_page_by_path( 'faq' );
	if ( $faq_page ) {
		$faq_id = $faq_page->ID;
	} else {
		$faq_id = wp_insert_post( array(
				'post_name'		=> 'faq',
				'post_title'	=> 'FAQ',
				'post_status'	=> 'publish',
				'post_type'		=> 'page',
				'menu_order'	=> 4,
				'page_template'	=> 'page-faq.php',
			) );
	}
	
	// サンプルページを draft に設定
	$sample_page = get_page_by_path( 'sample-page' );
	if ( $sample_page && 'publish' === $sample_page->post_status ) {
		wp_update_post( array(
			'ID'			=> $sample_page->ID,
			'post_status'	=> 'draft',
		) );
	}
}


// MW WP Form のセットアップ
function nsd_mw_form_setup() {
	// MW WP Form のお問い合わせを作成
	// // フォーム作成
	$forms = get_posts( array(
			'posts_per_page'	=> 1,
			'post_type'			=> 'mw-wp-form',
		) );
	if ( ! $forms ) {
		$post_content = <<<EOT
氏名（必須）
[mwform_text name="name"]

シメイ（必須）
[mwform_text name="furigana"]

TEL
[mwform_tel name="tel"]

MAIL（必須）
[mwform_email name="email"]

お問い合わせ内容（必須）
[mwform_textarea name="content"]

[mwform_submitButton name="submit" confirm_value="確認する" submit_value="送信する"]
EOT;
		$form_id = wp_insert_post( array(
				'post_name'		=> '%e3%81%8a%e5%95%8f%e3%81%84%e5%90%88%e3%82%8f%e3%81%9b',
				'post_title'	=> 'お問い合わせ',
				'post_status'	=> 'publish',
				'post_type'		=> 'mw-wp-form',
				'post_content'	=> $post_content,
			) );
		
		$mail_content = <<<EOT
お問い合わせをいただきまして、誠にありがとうございます。
こちらは自動返信の確認メールです。

名前:
{name}

フリガナ:
{furigana}

TEL:
{tel}

MAIL:
{email}

お問い合わせ内容:
{content}
EOT;
		$admin_mail_content = <<<EOT
お問い合わせを受け付けました。

名前:
{name}

フリガナ:
{furigana}

TEL:
{tel}

MAIL:
{email}

お問い合わせ内容:
{content}
EOT;
		$complete_message = <<<EOT
お問い合わせを受け付けました。

ありがとうございました。
EOT;
		$meta_value = array(
				'mail_subject'			=> 'お問い合わせを受け付けました',
				'mail_from'				=> '',
				'mail_sender'			=> '',
				'mail_content'			=> $mail_content,
				'automatic_reply_email'	=> 'email',
				'mail_to'				=> '',
				'mail_cc'				=> '',
				'mail_bcc'				=> '',
				'admin_mail_subject'	=> 'お問い合わせを受け付けました',
				'admin_mail_from'		=> '',
				'admin_mail_sender'		=> '',
				'admin_mail_content'	=> $admin_mail_content,
				'querystring'			=> false,
				'usedb'					=> false,
				'akismet_author'		=> '',
				'akismet_author_email'	=> '',
				'akismet_author_url'	=> '',
				'complete_message'		=> $complete_message,
				'input_url'				=> '',
				'confirmation_url'		=> '',
				'complete_url'			=> '',
				'validation_error_url'	=> '',
				'validation'			=> array(
						array(
								'target'	=> 'content',
								'noempty'	=> '1',
							),
						array(
								'target'	=> 'email',
								'noempty'	=> '1',
								'mail'		=> '1',
							),
						array(
								'target'	=> 'tel',
								'tel'		=> '1',
							),
						array(
								'target'	=> 'furigana',
								'noempty'	=> '1',
								'katakana'	=> '1',
							),
						array(
								'target'	=> 'name',
								'noempty'	=> '1',
							),
					),
				'style'					=> '',
				'scroll'				=> false,
			);
		add_post_meta( $form_id, 'mw-wp-form', $meta_value, true );
		
		// // 固定ページ作成
		$contact_page = get_page_by_path( 'contact' );
		if ( $contact_page ) {
			$contact_id = $contact_page->ID;
		} else {
			$contact_id = wp_insert_post( array(
					'post_name'		=> 'contact',
					'post_title'	=> 'お問い合わせ',
					'post_status'	=> 'publish',
					'post_type'		=> 'page',
					'post_content'	=> '[mwform_formkey key="' . $form_id . '"]',
					'menu_order'	=> 5,
				) );
		}
		
		// // ACF のお問い合わせURL設定
		if ( function_exists( 'get_field' ) && ! get_field( 'nsd_site_inquiry_url', 'option' ) ) {
			update_field( 'nsd_site_inquiry_url', get_permalink( get_page_by_path( 'contact' ) ), 'option' );
		}
	}
}


// ファーストビューを取得
function nsd_firstview() {
	return get_field( 'nsd_front_firstview_type', 'option' );
}


// メニュースタイルを取得
function nsd_menu_style() {
	$menu_style = ( 'standard' === nsd_firstview() || 'overleft' === nsd_firstview() ) ? 'full' : 'header';
	return apply_filters( 'nsd_menu_style', $menu_style );
}


// ロゴ位置を取得
function nsd_branding_position() {
	$branding_position = ( 'standard' === nsd_firstview() ) ? 'center' : 'left';
	return apply_filters( 'nsd_branding_position', $branding_position );
}


// スライダー位置を取得
function nsd_slider_position() {
	$slider_position = ( 'under' === nsd_firstview() ) ? 'over' : 'under';
	return apply_filters( 'nsd_slider_position', $slider_position );
}


// メニュー背景色を取得
function nsd_header_menu_bg_color() {
	if ( 'full' === nsd_menu_style() ) {
		return get_field( 'nsd_header_menu_bg_color', 'option' ) ? get_field( 'nsd_header_menu_bg_color', 'option' ) : '#ece7de';
	} else {
		return get_field( 'nsd_header_bg_color', 'option' ) ? get_field( 'nsd_header_bg_color', 'option' ) : '#ffffff';
	}
}


// テンプレートを取得
function nsd_get_template_name() {
	global $template;
	return basename( $template, '.php' );
}


// #firstview のクラス
function nsd_firstview_class() {
	$classes = array();
	
	$classes[] = 'firstview-' . esc_attr( nsd_firstview() );
	
	if ( 'over' === nsd_slider_position() && '#ffffff' === get_field( 'nsd_header_bg_color', 'option' ) ) {
		$classes[] = 'firstview-bottom-white';
	}
	
	echo implode( ' ', $classes );
}


// #footer のクラス
function nsd_footer_class() {
	$classes = array();
	
	$classes[] = nsd_text_color_class( get_field( 'nsd_footer_bg_color', 'option' ) );
	
	if ( get_field( 'nsd_main_bg_color', 'option' ) === get_field( 'nsd_footer_bg_color', 'option' ) ) {
		$classes[] = 'border-top';
	}
	
	echo implode( ' ', $classes );
}


/**
 * Allow to remove method for an hook when, it's a class method used and class don't have variable, but you know the class name :)
 */
function remove_filters_for_anonymous_class( $hook_name = '', $class_name ='', $method_name = '', $priority = 0 ) {
	global $wp_filter;
	
	// Take only filters on right hook name and priority
	if ( !isset($wp_filter[$hook_name][$priority]) || !is_array($wp_filter[$hook_name][$priority]) )
		return false;
	
	// Loop on filters registered
	foreach( (array) $wp_filter[$hook_name][$priority] as $unique_id => $filter_array ) {
		// Test if filter is an array ! (always for class/method)
		if ( isset($filter_array['function']) && is_array($filter_array['function']) ) {
			// Test if object is a class, class and method is equal to param !
			if ( is_object($filter_array['function'][0]) && get_class($filter_array['function'][0]) && get_class($filter_array['function'][0]) == $class_name && $filter_array['function'][1] == $method_name ) {
				unset($wp_filter[$hook_name][$priority][$unique_id]);
			}
		}
		
	}
	
	return false;
}

