<?php

//++++++++++++++++++++++++++++++++++++++++++++++++++++++
// ウィジェット追加

// お問い合わせバナーウィジェット
class NSD_Widget_Business_Banner extends WP_Widget {
	function __construct() {
		parent::__construct(
			'nsd_business_banner', // Base ID
			'会社概要・お問い合わせ', // Name
			array( 'description' => '会社概要のテキストと、お問い合わせボタンを表示します。', ) 
		);
	}
	
	function form( $instance ) {
		echo '<p>お問い合わせページのURLは、<a href="' . esc_url( admin_url() ) . 'admin.php?page=site">サイト設定</a>で設定してください。</p>';
	}
	
	function widget( $args, $instance ) {
		$widget_id = 'widget_' . $args['widget_id'];
		
		$description = get_field( 'description', $widget_id );
		$contact = get_field( 'contact', $widget_id );
		
		echo $args['before_widget'];
		
		if ( '' !== $description ) {
			echo '<h2 class="title">会社概要</h2>';
			echo '<div class="content post-content post-content-sidebar post-content-widget">'. $description . '</div>';
		}
		
		if ( '' !== $contact && get_field( 'nsd_site_inquiry_url', 'option' ) ) {
			echo '<div class="contact"><a href="' . esc_url( get_field( 'nsd_site_inquiry_url', 'option' ) ) . '" class="button-contact button-color">お問い合わせ</a></div>';
		}
		
		echo $args['after_widget'];
	}
}

// プロフィールウィジェット
class NSD_Widget_Profile extends WP_Widget {
	function __construct() {
		parent::__construct(
			'nsd_profile', // Base ID
			'プロフィール', // Name
			array( 'description' => 'プロフィールを表示します。', ) 
		);
	}
	
	function form( $instance ) {
	}
	
	function widget( $args, $instance ) {
		$widget_id = 'widget_' . $args['widget_id'];
		
		$widget_title = get_field( 'title', $widget_id );
		$name = get_field( 'name', $widget_id );
		$position = get_field( 'position', $widget_id );
		$image_id = get_field( 'image', $widget_id );
		$content = get_field( 'content', $widget_id );
		$facebook = get_field( 'facebook', $widget_id );
		$twitter = get_field( 'twitter', $widget_id );
		$instagram = get_field( 'instagram', $widget_id );
		
		echo $args['before_widget'];
		
		if ( '' !== $widget_title ) {
			echo $args['before_title'];
			echo esc_html( $widget_title );
			echo $args['after_title'];
		}
		
		echo '<div>';
		
		if ( '' !== $name || '' !== $position ) {
			echo '<header class="header">';
			
			if ( '' !== $name )
				echo '<h2 class="name">' . esc_html( $name ) . '</h2>';
			
			if ( '' !== $position )
				echo '<div class="position">' . esc_html( $position ) . '</div>';
			
			echo '</header>';
		}
		
		if ( $image_id )
			echo '<div class="image">' . wp_get_attachment_image( $image_id, 'medium' ) . '</div>';
		
		if ( $content )
			echo '<div class="description post-content post-content-sidebar post-content-widget">' . wp_kses_post( $content ) . '</div>';
		
		if ( $facebook || $twitter || $instagram ) {
			echo '<div class="sns">';
			
			if ( $facebook )
				echo '<a href="' . esc_url( 'https://www.facebook.com/' . urlencode( $facebook ) ) . '" class="facebook">Facebook</a>';
			
			if ( $twitter )
				echo '<a href="' . esc_url( 'https://twitter.com/' . urlencode( $twitter ) ) . '" class="twitter">Twitter</a>';
			
			if ( $instagram )
				echo '<a href="' . esc_url( 'https://www.instagram.com/' . urlencode( $instagram ) . '/' ) . '" class="instagram">Instagram</a>';
			
			echo '</div>';
		}
		
		echo '</div>';
		
		echo $args['after_widget'];
	}
}

// 告知ウィジェット
class NSD_Widget_Information extends WP_Widget {
	function __construct() {
		parent::__construct(
			'nsd_information', // Base ID
			'告知', // Name
			array( 'description' => '告知を表示します。', ) 
		);
	}
	
	function form( $instance ) {
	}
	
	function widget( $args, $instance ) {
		$widget_id = 'widget_' . $args['widget_id'];
		
		$widget_title = get_field( 'widget_title', $widget_id );
		$title = get_field( 'title', $widget_id );
		$content = get_field( 'content', $widget_id );
		$url = get_field( 'url', $widget_id );
		
		echo $args['before_widget'];
		
		if ( '' !== $widget_title ) {
			echo $args['before_title'];
			echo esc_html( $widget_title );
			echo $args['after_title'];
		}
		
		echo '<div>';
		
		if ( '' !== $url )
			echo '<a href="' . esc_url( $url ) . '" class="wrap">';
		else
			echo '<span class="wrap">';
		
		if ( '' !== $title )
			echo '<span class="title title-color">' . esc_html( $title ) . '</span>';
		
		if ( '' !== $content )
			echo '<span class="content">' . $content . '</span>';
		
		if ( '' !== $url )
			echo '</a>';
		else
			echo '</span>';
		
		echo '</div>';
		
		echo $args['after_widget'];
	}
}

// フリーボックスウィジェット
class NSD_Widget_Freebox extends WP_Widget {
	function __construct() {
		parent::__construct(
			'nsd_freebox', // Base ID
			'フリーボックス', // Name
			array( 'description' => '文章、画像を自由に表示します。', ) 
		);
	}
	
	function form( $instance ) {
	}
	
	function widget( $args, $instance ) {
		$widget_id = 'widget_' . $args['widget_id'];
		
		$title = get_field( 'title', $widget_id );
		$content = get_field( 'content', $widget_id );
		
		echo $args['before_widget'];
		
		if ( '' !== $title ) {
			echo $args['before_title'];
			echo esc_html( $title );
			echo $args['after_title'];
		}
		
		echo '<div>';
		
		if ( $content )
			echo '<div class="content post-content post-content-sidebar post-content-widget">' . wp_kses_post( $content ) . '</div>';
		
		echo '</div>';
		
		echo $args['after_widget'];
	}
}

// ウィジェット登録
add_action( 'widgets_init', 'nsd_register_widgets' );
function nsd_register_widgets() {
	register_widget( 'NSD_Widget_Business_Banner' );
	register_widget( 'NSD_Widget_Profile' );
	register_widget( 'NSD_Widget_Information' );
	register_widget( 'NSD_Widget_Freebox' );
}

