<?php

if ( ! class_exists( 'NS_License_Manager_Client' ) ) {

	class NS_License_Manager_Client {
		private $product_license_id = 'new-standard';
		
		private $product_id;
		
		private $product_name;
		
		private $api_endpoint = 'http://newstd.net/api/license-manager/v1';
		
		public function __construct( $product_id, $product_name ) {
			$this->product_id = $product_id;
			$this->product_name = $product_name;
			
			if ( is_multisite() && is_network_admin() ) {
				add_action( 'network_admin_menu', array( $this, 'add_license_settings_page' ), 100 );
				add_action( 'admin_init', array( $this, 'add_license_settings_fields' ) );
				add_action( 'network_admin_edit_' . $this->get_settings_field_name(), array( $this, 'network_admin_edit' ) );
			} elseif ( ! is_multisite() && is_admin() ) {
				add_action( 'admin_menu', array( $this, 'add_license_settings_page' ), 100 );
				add_action( 'admin_init', array( $this, 'add_license_settings_fields' ) );
			}
			
			add_action( 'network_admin_notices', array( $this, 'show_user_notices' ) );
			add_action( 'admin_notices', array( $this, 'show_user_notices' ) );
			add_action( 'admin_notices', array( $this, 'show_license_notices' ) );
			
			add_filter( 'pre_set_site_transient_update_themes', array( $this, 'check_for_update' ), 10, 2 );
			add_filter( 'pre_set_site_transient_update_plugins', array( $this, 'check_for_update' ), 10, 2 );
			
			add_action( 'admin_head', array( $this, 'wp_update_themes_or_plugins' ) );
			
			add_filter( 'plugins_api', array( $this, 'plugins_api_handler' ), 10, 3 );
			
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_styles' ) );
		}
		
		private function get_options() {
			return is_multisite() ? get_site_option( $this->get_settings_field_name(), array() ) : get_option( $this->get_settings_field_name(), array() );
		}
		
		private function get_option( $key, $default = false ) {
			$options = $this->get_options();
			return isset( $options[ $key ] ) ? $options[ $key ] : $default;
		}
		
		private function update_options( $options ) {
			return is_multisite() ? update_site_option( $this->get_settings_field_name(), $options ) : update_option( $this->get_settings_field_name(), $options );
		}
		
		private function update_option( $key, $value ) {
			$options = $this->get_options();
			$options[ $key ] = $value;
			return $this->update_options( $options );
		}
		
		public function add_license_settings_page() {
			if ( is_multisite() ) {
				$title = 'New Standard ライセンス';
				$parent = 'themes.php';
			} else {
				$title = 'ライセンス';
				$parent = 'nyt-site';
			}
			
			add_submenu_page(
				$parent,
				$title,
				$title,
				'read',
				$this->get_settings_page_slug(),
				array( $this, 'render_licenses_menu' )
			);
		}
		
		public function add_license_settings_fields() {
			$settings_group_id = $this->product_license_id . '-license-settings-group';
			$settings_section_id = $this->product_license_id . '-license-settings-section';
			
			register_setting( $settings_group_id, $this->get_settings_field_name() );
			
			add_settings_section(
				$settings_section_id,
				'ライセンス',
				array( $this, 'render_settings_section' ),
				$settings_group_id
			);
			
			add_settings_field(
				$this->product_license_id . '-license-email',
				'メールアドレス',
				array( $this, 'render_email_settings_field' ),
				$settings_group_id,
				$settings_section_id
			);
			
			add_settings_field(
				$this->product_license_id . '-license-key',
				'ライセンスキー',
				array( $this, 'render_license_key_settings_field' ),
				$settings_group_id,
				$settings_section_id
			);
			
			add_settings_field(
				$this->product_license_id . '-license-table',
				'ライセンス一覧',
				array( $this, 'render_license_table_field' ),
				$settings_group_id,
				$settings_section_id
			);
		}
		
		public function render_settings_section() {
			if ( $this->get_option( 'email' ) && $this->get_option( 'license_key' ) ) {
				
				$error = $this->get_api_error();
				
				if ( isset( $error->code ) ) {
					switch ( $error->code ):
						case '101':
							?>
							<p style="color:red;">
								ライセンスが見つかりません。ライセンスキーとメールアドレスをご確認ください。
							</p>
							<?php
							break;
						case '103':
							?>
							<p style="color:red;">
								ご使用中のサイトは、ライセンスに登録されているURLと一致しません。
							</p>
							<?php
							break;
						case '801':
							?>
							<p style="color:red;">
								ライセンス認証の通信に失敗しました。
							</p>
							
							<p>
								しばらくしてから、再度ご確認ください。<br />
								それでも失敗する場合には、ライセンス管理者にお問い合わせください。
							</p>
							<?php
							break;
						default:
							?>
							<p style="color:red;">
								無効なライセンスです。
							</p>
							<?php
					endswitch;
				} elseif ( $this->get_option( 'validation' ) ) {
					echo '<p style="color:green;">ライセンスは有効です。</p>';
				}
			} else {
				echo '<p>ライセンス情報を入力して、更新機能を有効にしてください。</p>';
			}
		}
		
		public function render_licenses_menu() {
			$title = $this->product_name . 'のライセンス';
			$settings_group_id = $this->product_license_id . '-license-settings-group';
			$action_url = is_multisite() ? 'edit.php?action=' . $this->get_settings_field_name() : 'options.php';
			
			?>
				<div class="wrap">
					<form action='<?php echo esc_attr( $action_url ) ?>' method='post'>
						
						<h1><?php echo $title; ?></h1>
						
						<?php
							settings_fields( $settings_group_id );
							do_settings_sections( $settings_group_id );
							submit_button();
						?>
						
					</form>
				</div>
			<?php
		}
		
		public function render_email_settings_field() {
			$settings_field_name = $this->get_settings_field_name();
			?>
				<input type='text' name='<?php echo $settings_field_name; ?>[email]'
					 value='<?php echo esc_attr( $this->get_option( 'email', '' ) ); ?>' class='regular-text'>
			<?php
		}
		
		public function render_license_key_settings_field() {
			$settings_field_name = $this->get_settings_field_name();
			?>
				<input type='text' name='<?php echo $settings_field_name; ?>[license_key]'
					 value='<?php echo esc_attr( $this->get_option( 'license_key', '' ) ); ?>' class='regular-text'>
			<?php
		}
		
		public function render_license_table_field() {
			$licenses = $this->get_option( 'licenses' );
			if ( is_array( $licenses ) ) :
				?>
				<table class="ns-license-manager-table">
					<thead>
						<tr>
							<th>名前</th>
							<th>種類</th>
							<th>有効期限</th>
						</tr>
					</thead>
					
					<tbody>
						<?php foreach( $licenses as $license ) : ?>
							<?php
								switch ( $license->valid_until ):
									case 'expired' :
										$valid_until = '期限切れ';
										break;
									case 'unlimited' :
										$valid_until = '無期限';
										break;
									default:
										$valid_until = esc_html( $license->valid_until );
								endswitch;
							?>
							<tr>
								<td><?php echo esc_html( $license->name ); ?></td>
								<td><?php echo 'theme' === $license->type ? 'テーマ' : 'プラグイン'; ?></td>
								<td><?php echo $valid_until; ?></td>
							</tr>
						<?php endforeach; ?>
					</tbody>
				</table>
				<?php
			endif;
		}
		
		public function network_admin_edit() {
			$settings_group_id = $this->product_license_id . '-license-settings-group';
			
			check_admin_referer( $settings_group_id . '-options' );
			
			$options = $this->get_options();
			
			if ( isset( $_POST[ $this->get_settings_field_name() ] ) ) {
				$post = $_POST[ $this->get_settings_field_name() ];
				
				if ( is_array( $post ) ) {
					foreach ( $post as $key => $value ) {
						$options[ $key ] = $value;
					}
					
					$this->update_options( $options );
				}
			}
			
			wp_redirect( add_query_arg( array( 'page' => $this->get_settings_page_slug() ), network_admin_url( 'themes.php' ) ) );
			exit;
		}
		
		protected function get_settings_field_name() {
			return 'nyt-' . $this->product_license_id . '-license-settings';
		}
		
		protected function get_settings_page_slug() {
			return 'nyt-' . $this->product_license_id . '-licenses';
		}
		
		public function show_user_notices() {
			if ( ( ! isset( $_GET['page'] ) || $this->get_settings_page_slug() !== $_GET['page'] ) && ! $this->get_option( 'validation' ) ) {
				$msg = $this->product_name . ' のライセンス情報を入力して、更新機能を有効にしてください。';
				?>
					<div class="notice notice-warning is-dismissible">
						<p>
							<?php echo $msg; ?>
						</p>
						
						<p>
							<?php if ( is_multisite() && ! current_user_can( 'manage_network' ) ) : ?>
								※ライセンス情報の入力は、特権管理者の権限を持ったユーザが行なえます。
							<?php else : ?>
								<a href="<?php echo $this->get_setting_url(); ?>">
									ライセンス情報を入力する
								</a>
							<?php endif; ?>
						</p>
					</div>
				<?php
			}
		}
		
		public function show_license_notices() {
			if ( $this->get_option( 'validation' ) ) {
				$licenses = $this->get_option( 'licenses' );
				
				$message = '';
				if ( is_array( $licenses ) && $license = $this->find_license( $licenses, $this->product_id, 'theme' ) ) {
					if ( isset( $license->valid_until ) && 'expired' === $license->valid_until ) {
						$message = '<p>' . $this->product_name . ' のライセンスの有効期限が切れています。ライセンスを延長して更新機能を有効にしてください。</p>' . "\n";
						if ( ( ! isset( $_GET['page'] ) || $this->get_settings_page_slug() !== $_GET['page'] ) ) {
							if ( is_multisite() && ! current_user_can( 'manage_network' ) ) {
								$message .= '<p>※ライセンス情報の確認は、特権管理者の権限を持ったユーザが行なえます。</p>';
							} else {
								$message .= '<p><a href="' . $this->get_setting_url() . '">ライセンスを確認する</a></p>';
							}
						}
						$message = apply_filters( 'nslm_expired_theme_notice', $message, $this->product_name, $this->product_id );
					}
				} else {
					$message = '<p>' . $this->product_name . ' のライセンスがありません。ライセンスを取得して更新機能を有効にしてください。</p>' . "\n";
					if ( ( ! isset( $_GET['page'] ) || $this->get_settings_page_slug() !== $_GET['page'] ) ) {
						if ( is_multisite() && ! current_user_can( 'manage_network' ) ) {
							$message .= '<p>※ライセンス情報の確認は、特権管理者の権限を持ったユーザが行なえます。</p>';
						} else {
							$message .= '<p><a href="' . $this->get_setting_url() . '">ライセンスを確認する</a></p>';
						}
					}
					$message = apply_filters( 'nslm_invalid_theme_notice', $message, $this->product_name, $this->product_id );
				}
				
				if ( '' !== $message ) {
					echo '<div class="notice notice-warning is-dismissible">' . "\n";
					echo wp_kses_post( $message ) . "\n";
					echo '</div>' . "\n";
				}
				
				$plugins = apply_filters( 'nslm_active_plugins', array() );
				foreach( $plugins as $plugin ) {
					if ( isset( $plugin['name'] ) && isset( $plugin['slug'] ) ) {
						$message = '';
						$name = $plugin['name'];
						$slug = $plugin['slug'];
						
						if ( $license = $this->find_license( $licenses, $slug, 'plugin' ) ) {
							if ( isset( $license->valid_until ) && 'expired' === $license->valid_until ) {
								$message = '<p>' . $name . ' のライセンスの有効期限が切れています。ライセンスを延長して更新機能を有効にしてください。</p>' . "\n";
								if ( ( ! isset( $_GET['page'] ) || $this->get_settings_page_slug() !== $_GET['page'] ) ) {
									if ( is_multisite() && ! current_user_can( 'manage_network' ) ) {
										$message .= '<p>※ライセンス情報の確認は、特権管理者の権限を持ったユーザが行なえます。</p>';
									} else {
										$message .= '<p><a href="' . $this->get_setting_url() . '">ライセンスを確認する</a></p>';
									}
								}
								$message = apply_filters( 'nslm_expired_plugin_notice', $message, $name, $slug );
								$message = apply_filters( 'nslm_expired_plugin_' . $slug . '_notice', $message, $name );
							}
						} else {
							$message = '<p>' . $name . ' のライセンスがありません。ライセンスを取得して更新機能を有効にしてください。</p>' . "\n";
							if ( ( ! isset( $_GET['page'] ) || $this->get_settings_page_slug() !== $_GET['page'] ) ) {
								if ( is_multisite() && ! current_user_can( 'manage_network' ) ) {
									$message .= '<p>※ライセンス情報の確認は、特権管理者の権限を持ったユーザが行なえます。</p>';
								} else {
									$message .= '<p><a href="' . $this->get_setting_url() . '">ライセンスを確認する</a></p>';
								}
							}
							$message = apply_filters( 'nslm_invalid_plugin_notice', $message, $name, $slug );
							$message = apply_filters( 'nslm_invalid_plugin_' . $slug . '_notice', $message, $name, $slug );
						}
						
						if ( '' !== $message ) {
							echo '<div class="notice notice-warning is-dismissible">' . "\n";
							echo wp_kses_post( $message ) . "\n";
							echo '</div>' . "\n";
						}
					}
				}
			}
		}
		
		private function find_license( $licenses, $slug, $type ) {
			foreach ( (array)$licenses as $license ) {
				if ( isset( $license->slug ) && $slug === $license->slug && isset( $license->type ) && $type === $license->type ) {
					return $license;
				}
			}
			
			return false;
		}
		
		private function get_setting_url() {
			return is_multisite() ? network_admin_url( 'themes.php?page=' . $this->get_settings_page_slug() ) : admin_url( 'admin.php?page=' . $this->get_settings_page_slug() );
		}
		
		private function call_api( $action, $params ) {
			$response_body = get_transient( $this->get_settings_field_name() . '-api' );
			
			if ( $response_body ) {
				$result = json_decode( $response_body );
			} else {
				$url = $this->api_endpoint . '/' . $action;
				
				$url .= '?' . http_build_query( $params );
				
				$response = wp_remote_get( $url, array( 'decompress' => false ) );
				
				if ( is_wp_error( $response ) ) {
					return false;
				}
				
				$response_body = wp_remote_retrieve_body( $response );
				$result = json_decode( $response_body );
				
				if ( ! is_object( $result ) ) {
					return false;
				}
				
				set_transient( $this->get_settings_field_name() . '-api', $response_body, 5 ); //  5 sec.
			}
			
			return $result;
		}
		
		private function is_api_error( $response ) {
			if ( $response === false || ! is_object( $response ) ) {
				$this->save_api_error( (object) array(
					'code'		=> '801',
					'message'	=> '認証の通信に失敗しました。'
				) );
				return true;
			}
			
			if ( isset( $response->error ) ) {
				$this->save_api_error( $response->error );
				return true;
			}
			
			$this->remove_api_error();
			return false;
		}
		
		private function save_api_error( $error ) {
			$this->update_option( 'error', $error );
		}
		
		private function remove_api_error() {
			$this->update_option( 'error', '' );
		}
		
		private function get_api_error() {
			$error = $this->get_option( 'error' );
			
			return $error ? $error : false;
		}
		
		public function get_user_info() {
			$email = $this->get_option( 'email' );
			$license_key = $this->get_option( 'license_key' );
			
			if ( ! $email || ! $license_key ) {
				return false;
			}
			
			$info = $this->call_api(
				'user_info',
				array(
					'e' => $email,
					'l' => $license_key,
					'u' => home_url(),
				)
			);
			
			return $info;
		}
		
		public function check_user_validation() {
			$user_info = $this->get_user_info();
			
			if ( $this->is_api_error( $user_info ) ) {
				$error = $this->get_api_error();
				
				if ( ! isset( $error->code ) || '801' !== $error->code ) {
					$this->update_option( 'validation', false );
					$this->update_option( 'licenses', false );
				}
				return false;
			} else {
				$this->update_option( 'validation', true );
				$this->update_option( 'licenses', $user_info->licenses );
				return $user_info;
			}
		}
		
		public function is_update_available( $license_info ) {
			if ( 'theme' === $license_info->type ) {
				$theme_data = wp_get_theme( $license_info->slug );
				
				if ( $theme_data->exists() && version_compare( $license_info->version, $theme_data->get( 'Version' ), '>' ) ) {
					return true;
				}
			} else {
				$plugin_dir = WP_PLUGIN_DIR . '/' . $license_info->slug . '/' . $license_info->slug . '.php';
				
				if ( file_exists( $plugin_dir ) ) {
					$plugin_data = get_plugin_data( $plugin_dir, false );
					
					if ( $plugin_data && version_compare( $license_info->version, $plugin_data['Version'], '>' ) ) {
						return true;
					}
				}
			}
			
			return false;
		}
		
		public function check_for_update( $value, $transient ) {
			$user_info = $this->check_user_validation();
			
			if ( $user_info !== false && isset( $user_info->licenses ) && is_array( $user_info->licenses ) ) {
				foreach ( $user_info->licenses as $license ) {
					if ( $transient !== 'update_' . $license->type . 's' )
						continue;
					
					if ( 'expired' !== $license->valid_until ) {
						$license_info = $license->info;
						
						if ( $this->is_update_available( $license_info ) ) {
							if ( 'update_themes' === $transient && 'theme' === $license_info->type ) {
								$value->response[ $license_info->slug ] = array(
									'new_version' => $license_info->version,
									'package' => $license_info->package_url,
									'url' => $license_info->description_url
								);
							} elseif ( 'update_plugins' === $transient && 'plugin' === $license_info->type ) {
					            $value->response[ $license_info->slug . '/' . $license_info->slug . '.php' ] = (object) array(
									'new_version' => $license_info->version,
									'package' => $license_info->package_url,
									'slug' => $license_info->slug
					            );
							}
						}
					}
				}
			}
			
			return $value;
		}
		
		public function plugins_api_handler( $res, $action, $args ) {
			$licenses = $this->get_option( 'licenses' );
			
			if ( is_array( $licenses ) && $action == 'plugin_information' ) {
				
				if ( isset( $args->slug ) ) {
					foreach ( $licenses as $license ) {
						$info = $license->info;
						if ( $args->slug == $info->slug ) {
							$res = (object) array(
								'name' => isset( $info->name ) ? $info->name : '',
								'version' => $info->version,
								'slug' => $args->slug,
								'download_link' => $info->package_url,
								
								'tested' => isset( $info->tested ) ? $info->tested : '',
								'requires' => isset( $info->requires ) ? $info->requires : '',
								'last_updated' => isset( $info->last_updated ) ? $info->last_updated : '',
								'homepage' => isset( $info->description_url ) ? $info->description_url : '',
								
								'sections' => array(
									'description' => $info->description,
								),
								
								'banners' => array(
									'low' => isset( $info->banner_low ) ? $info->banner_low : '',
									'high' => isset( $info->banner_high ) ? $info->banner_high : ''
								),
								
								'external' => true
							);
							
							if ( isset( $info->changelog ) ) {
								$res['sections']['changelog'] = $info->changelog;
							}
							
							return $res;
						}
					}
				}
			}
			
			return false;
		}
		
		public function wp_update_themes_or_plugins() {
			if ( isset( $_GET['page'] ) && $this->get_settings_page_slug() === $_GET['page'] ) {
				$this->check_user_validation();
				
				wp_update_themes();
				wp_update_plugins();
			}
		}
		
		public function admin_enqueue_styles() {
			wp_enqueue_style( 'ns-license-manager-theme', get_template_directory_uri() . '/inc/license/css/ns-license-manager.css', array(), wp_theme_version() );
		}
	}
}
